@@ -33,16 +33,23 @@ basePkgs <- function()names(which(installed.packages()[, "Priority"] == "base"))
 #'
 #' @param depends If TRUE, retrieves `Depends`, `Imports` and `LinkingTo` dependencies
 #'   (non-recursively)
+#'   
 #' @param suggests If TRUE, retrieves Suggests dependencies (non-recursively)
+#' 
 #' @param enhances If TRUE, retrieves Enhances dependencies (non-recursively)
+#' 
 #' @param quiet If TRUE, suppresses warnings
 #'
 #' @param includeBasePkgs If TRUE, include base R packages in results
+#' 
 #' @template Rversion
+#' 
 #' @param ... Other arguments passed to [available.packages()]
 #'
 #' @export
 #' @family dependency functions
+#' 
+#' @return character vector of package names
 #'
 #' @example /inst/examples/example_pkgDep.R
 #'   
@@ -120,6 +127,7 @@ pkgDep <- function(pkg, availPkgs, repos = getOption("repos"), type = "source",
     p_all = p_all
     )
   class(ret) <- c("pkgDep", "character")
+  assert_that(is_package_vector(ret))
   ret
 }
 
@@ -144,7 +152,8 @@ print.pkgDep <- function(x, ...) {
 pkgAvail <- function(repos = getOption("repos"), 
                      type = "source", 
                      Rversion = R.version, quiet = FALSE) {
-  if (!grepl("^http://|file:///", repos[1]) && file.exists(repos[1])) {
+  assert_that(is_repos(repos))
+  if (!grepl("^https*://|file:///", repos[1]) && file.exists(repos[1])) {
      repos <- paste0("file:///", normalizePath(repos[1],
                                                mustWork = FALSE, 
                                                winslash = "/"))
