@@ -2,7 +2,6 @@ if (interactive()) library(testthat)
 
 # Copyright (c) Andrie de Vries 2018
 
-context("github-functions")
 
 test_that("package file extension is computed correctly", {
   expect_equal(pkgFileExt("source"), ".tar.gz")
@@ -19,27 +18,32 @@ test_that("package verson is extracted correctly", {
     "Matrix_1.2-12.tar.gz",
     "boot_1.3-20.tar.gz"
   )
-  expect_equal(
-    getPkgVersFromFile(ff),
-    data.frame(
-      package = c("boot", "KernSmooth", "MASS", "Matrix"),
-      version = c("1.3-20", "2.23-15", "7.3-47", "1.2-12"),
-      stringsAsFactors = FALSE,
-      row.names = NULL
-    )
+  df <- data.frame(
+    package = c("boot", "KernSmooth", "MASS", "Matrix"),
+    version = c("1.3-20", "2.23-15", "7.3-47", "1.2-12"),
+    stringsAsFactors = FALSE
   )
   
+  # <don't understand> why we need to reorder to get tests to pass
+  df <- df[order(df$package), ]
+  row.names(df) <- seq_len(nrow(df))
+  # </don't understand>
+  
+  expect_equal(
+    getPkgVersFromFile(ff),
+    df
+  )
+
   expect_equal(
     getPkgVersFromFile("nonsense"),
-    data.frame(package = character(0), version = character(0))
-    )
-  
+    data.frame(package = character(0), version = character(0), stringsAsFactors = FALSE)
+  )
 })
 
 test_that("readDescription reads file", {
   sf <- system.file("DESCRIPTION", package = "miniCRAN")
   desc <- readDescription(sf)
-  
+
   expect_is(desc, "list")
   expect_true(
     all(c("Imports", "Suggests", "Package") %in% names(desc))
